# Polars Extensions

This library is designed to extend the capabilities of polars with functionalities that are not currently found in Polars. 

## Usage

[Jupyter Walkthrough](https://github.com/jrasband-dev/polars-extensions/blob/main/usage.ipynb)


## Extensions

### IO functions
* Read Schema 
* Write Schema

### Geospatial Expressions (geo_ext)
Quick geospatial calulations.

* Convert from WKT to Coords 
* Convert from Coords to WKT
* Convert from WKB to Coords
* Convert from Coords to WKB

### Numeric Expressions (num_ext)
* Convert Numbers to Roman Numerals 
* Convert Roman Numerals to Numbers
* Convert Textual Number Representations to Actual Numbers

### Column Naming Expressions (name_ext)
Automatically change column naming conventions

* Snake Case
* Pascal Case
* Pascal Snake Case
* Camel Case
* Camel Snake Case
* Kebeb Case
* Train Case
* Upper Snake Case

### String Expressions (str_ext)
* F1 Similarity

